@@ -215,6 +215,7 @@ USAGE: ${PROGRAM} [options]
   --disable-plugin-xenstat   Explicitly disable the xenstat plugin.
   --enable-plugin-systemd-journal Enable the systemd journal plugin. Default: enable it when libsystemd is available.
   --disable-plugin-systemd-journal Explicitly disable the systemd journal plugin.
+  --internal-systemd-journal Enable the internal journal file reader instead of using libsystemd
   --enable-exporting-kinesis Enable AWS Kinesis exporting connector. Default: enable it when libaws_cpp_sdk_kinesis
                              and its dependencies are available.
   --disable-exporting-kinesis Explicitly disable AWS Kinesis exporting connector.
@@ -294,6 +295,7 @@ while [ -n "${1}" ]; do
     "--disable-plugin-xenstat") ENABLE_XENSTAT=0 ;;
     "--enable-plugin-systemd-journal") ENABLE_SYSTEMD_JOURNAL=1 ;;
     "--disable-plugin-systemd-journal") ENABLE_SYSTEMD_JOURNAL=0 ;;
+    "--internal-systemd-journal") USE_RUST_JOURNAL_FILE=1 ;;
     "--enable-exporting-kinesis" | "--enable-backend-kinesis")
       # TODO: Needs CMake Support
       ;;
