@@ -59,8 +59,6 @@ struct rrdengine_datafile {
     uv_rwlock_t extent_rwlock;
     struct rrdengine_instance *ctx;
     struct rrdengine_journalfile *journalfile;
-    struct rrdengine_datafile *prev;
-    struct rrdengine_datafile *next;
 
     struct {
         SPINLOCK spinlock;
@@ -94,14 +92,14 @@ void datafile_release_with_trace(struct rrdengine_datafile *df, DATAFILE_ACQUIRE
 #define datafile_release(df, reason) datafile_release_with_trace(df, reason, __FUNCTION__)
 bool datafile_acquire_for_deletion(struct rrdengine_datafile *df, bool is_shutdown);
 
-void datafile_list_insert(struct rrdengine_instance *ctx, struct rrdengine_datafile *datafile, bool having_lock);
+void datafile_list_insert(struct rrdengine_instance *ctx, struct rrdengine_datafile *datafile);
 void datafile_list_delete_unsafe(struct rrdengine_instance *ctx, struct rrdengine_datafile *datafile);
 void generate_datafilepath(struct rrdengine_datafile *datafile, char *str, size_t maxlen);
 int close_data_file(struct rrdengine_datafile *datafile);
 int unlink_data_file(struct rrdengine_datafile *datafile);
 int destroy_data_file_unsafe(struct rrdengine_datafile *datafile);
 int create_data_file(struct rrdengine_datafile *datafile);
-int create_new_datafile_pair(struct rrdengine_instance *ctx, bool having_lock);
+int create_new_datafile_pair(struct rrdengine_instance *ctx);
 int init_data_files(struct rrdengine_instance *ctx);
 void finalize_data_files(struct rrdengine_instance *ctx);
 void cleanup_datafile_epdl_structures(struct rrdengine_datafile *datafile);
