@@ -22,7 +22,10 @@ where
 `
 
 func (c *Collector) collectSystemAsyncMetrics(mx map[string]int64) error {
-	req, _ := web.NewHTTPRequest(c.RequestConfig)
+	req, err := web.NewHTTPRequest(c.RequestConfig)
+	if err != nil {
+		return err
+	}
 	req.URL.RawQuery = makeURLQuery(querySystemAsyncMetrics)
 
 	want := map[string]float64{
@@ -35,7 +38,7 @@ func (c *Collector) collectSystemAsyncMetrics(mx map[string]int64) error {
 	var metric string
 	var n int
 
-	err := c.doHTTP(req, func(column, value string, lineEnd bool) {
+	err = c.doHTTP(req, func(column, value string, lineEnd bool) {
 		switch column {
 		case "metric":
 			metric = value
