@@ -1,7 +1,5 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 
-//go:build linux || freebsd || openbsd || netbsd || dragonfly
-
 package smartctl
 
 import (
@@ -290,6 +288,125 @@ func TestCollector_Collect(t *testing.T) {
 				"device_sdc_type_sat_temperature":                             27,
 			},
 		},
+		"success type sata devices concurrent": {
+			prepareMock: prepareMockOkTypeSata,
+			prepareConfig: func() Config {
+				cfg := New().Config
+				cfg.ConcurrentScans = 2
+				return cfg
+			},
+			wantCharts: 68,
+			wantMetrics: map[string]int64{
+				"device_sda_type_sat_ata_smart_error_log_summary_count":       0,
+				"device_sda_type_sat_attr_current_pending_sector_decoded":     0,
+				"device_sda_type_sat_attr_current_pending_sector_normalized":  100,
+				"device_sda_type_sat_attr_current_pending_sector_raw":         0,
+				"device_sda_type_sat_attr_load_cycle_count_decoded":           360,
+				"device_sda_type_sat_attr_load_cycle_count_normalized":        100,
+				"device_sda_type_sat_attr_load_cycle_count_raw":               360,
+				"device_sda_type_sat_attr_offline_uncorrectable_decoded":      0,
+				"device_sda_type_sat_attr_offline_uncorrectable_normalized":   100,
+				"device_sda_type_sat_attr_offline_uncorrectable_raw":          0,
+				"device_sda_type_sat_attr_power-off_retract_count_decoded":    360,
+				"device_sda_type_sat_attr_power-off_retract_count_normalized": 100,
+				"device_sda_type_sat_attr_power-off_retract_count_raw":        360,
+				"device_sda_type_sat_attr_power_cycle_count_decoded":          12,
+				"device_sda_type_sat_attr_power_cycle_count_normalized":       100,
+				"device_sda_type_sat_attr_power_cycle_count_raw":              12,
+				"device_sda_type_sat_attr_power_on_hours_decoded":             8244,
+				"device_sda_type_sat_attr_power_on_hours_normalized":          99,
+				"device_sda_type_sat_attr_power_on_hours_raw":                 8244,
+				"device_sda_type_sat_attr_raw_read_error_rate_decoded":        0,
+				"device_sda_type_sat_attr_raw_read_error_rate_normalized":     100,
+				"device_sda_type_sat_attr_raw_read_error_rate_raw":            0,
+				"device_sda_type_sat_attr_reallocated_event_count_decoded":    0,
+				"device_sda_type_sat_attr_reallocated_event_count_normalized": 100,
+				"device_sda_type_sat_attr_reallocated_event_count_raw":        0,
+				"device_sda_type_sat_attr_reallocated_sector_ct_decoded":      0,
+				"device_sda_type_sat_attr_reallocated_sector_ct_normalized":   100,
+				"device_sda_type_sat_attr_reallocated_sector_ct_raw":          0,
+				"device_sda_type_sat_attr_seek_error_rate_decoded":            0,
+				"device_sda_type_sat_attr_seek_error_rate_normalized":         100,
+				"device_sda_type_sat_attr_seek_error_rate_raw":                0,
+				"device_sda_type_sat_attr_seek_time_performance_decoded":      15,
+				"device_sda_type_sat_attr_seek_time_performance_normalized":   140,
+				"device_sda_type_sat_attr_seek_time_performance_raw":          15,
+				"device_sda_type_sat_attr_spin_retry_count_decoded":           0,
+				"device_sda_type_sat_attr_spin_retry_count_normalized":        100,
+				"device_sda_type_sat_attr_spin_retry_count_raw":               0,
+				"device_sda_type_sat_attr_spin_up_time_decoded":               281,
+				"device_sda_type_sat_attr_spin_up_time_normalized":            86,
+				"device_sda_type_sat_attr_spin_up_time_raw":                   25788088601,
+				"device_sda_type_sat_attr_start_stop_count_decoded":           12,
+				"device_sda_type_sat_attr_start_stop_count_normalized":        100,
+				"device_sda_type_sat_attr_start_stop_count_raw":               12,
+				"device_sda_type_sat_attr_temperature_celsius_decoded":        49,
+				"device_sda_type_sat_attr_temperature_celsius_normalized":     43,
+				"device_sda_type_sat_attr_temperature_celsius_raw":            240519741489,
+				"device_sda_type_sat_attr_throughput_performance_decoded":     48,
+				"device_sda_type_sat_attr_throughput_performance_normalized":  148,
+				"device_sda_type_sat_attr_throughput_performance_raw":         48,
+				"device_sda_type_sat_attr_udma_crc_error_count_decoded":       0,
+				"device_sda_type_sat_attr_udma_crc_error_count_normalized":    100,
+				"device_sda_type_sat_attr_udma_crc_error_count_raw":           0,
+				"device_sda_type_sat_attr_unknown_attribute_decoded":          100,
+				"device_sda_type_sat_attr_unknown_attribute_normalized":       100,
+				"device_sda_type_sat_attr_unknown_attribute_raw":              100,
+				"device_sda_type_sat_power_cycle_count":                       12,
+				"device_sda_type_sat_power_on_time":                           29678400,
+				"device_sda_type_sat_smart_status_failed":                     0,
+				"device_sda_type_sat_smart_status_passed":                     1,
+				"device_sda_type_sat_temperature":                             49,
+				"device_sdc_type_sat_ata_smart_error_log_summary_count":       0,
+				"device_sdc_type_sat_attr_available_reservd_space_decoded":    100,
+				"device_sdc_type_sat_attr_available_reservd_space_normalized": 100,
+				"device_sdc_type_sat_attr_available_reservd_space_raw":        100,
+				"device_sdc_type_sat_attr_command_timeout_decoded":            0,
+				"device_sdc_type_sat_attr_command_timeout_normalized":         100,
+				"device_sdc_type_sat_attr_command_timeout_raw":                0,
+				"device_sdc_type_sat_attr_end-to-end_error_decoded":           0,
+				"device_sdc_type_sat_attr_end-to-end_error_normalized":        100,
+				"device_sdc_type_sat_attr_end-to-end_error_raw":               0,
+				"device_sdc_type_sat_attr_media_wearout_indicator_decoded":    65406,
+				"device_sdc_type_sat_attr_media_wearout_indicator_normalized": 100,
+				"device_sdc_type_sat_attr_media_wearout_indicator_raw":        65406,
+				"device_sdc_type_sat_attr_power_cycle_count_decoded":          13,
+				"device_sdc_type_sat_attr_power_cycle_count_normalized":       100,
+				"device_sdc_type_sat_attr_power_cycle_count_raw":              13,
+				"device_sdc_type_sat_attr_power_on_hours_decoded":             8244,
+				"device_sdc_type_sat_attr_power_on_hours_normalized":          100,
+				"device_sdc_type_sat_attr_power_on_hours_raw":                 8244,
+				"device_sdc_type_sat_attr_reallocated_sector_ct_decoded":      0,
+				"device_sdc_type_sat_attr_reallocated_sector_ct_normalized":   100,
+				"device_sdc_type_sat_attr_reallocated_sector_ct_raw":          0,
+				"device_sdc_type_sat_attr_reported_uncorrect_decoded":         0,
+				"device_sdc_type_sat_attr_reported_uncorrect_normalized":      100,
+				"device_sdc_type_sat_attr_reported_uncorrect_raw":             0,
+				"device_sdc_type_sat_attr_temperature_celsius_decoded":        27,
+				"device_sdc_type_sat_attr_temperature_celsius_normalized":     73,
+				"device_sdc_type_sat_attr_temperature_celsius_raw":            184684970011,
+				"device_sdc_type_sat_attr_total_lbas_read_decoded":            76778,
+				"device_sdc_type_sat_attr_total_lbas_read_normalized":         253,
+				"device_sdc_type_sat_attr_total_lbas_read_raw":                76778,
+				"device_sdc_type_sat_attr_total_lbas_written_decoded":         173833,
+				"device_sdc_type_sat_attr_total_lbas_written_normalized":      253,
+				"device_sdc_type_sat_attr_total_lbas_written_raw":             173833,
+				"device_sdc_type_sat_attr_udma_crc_error_count_decoded":       0,
+				"device_sdc_type_sat_attr_udma_crc_error_count_normalized":    100,
+				"device_sdc_type_sat_attr_udma_crc_error_count_raw":           0,
+				"device_sdc_type_sat_attr_unknown_attribute_decoded":          0,
+				"device_sdc_type_sat_attr_unknown_attribute_normalized":       0,
+				"device_sdc_type_sat_attr_unknown_attribute_raw":              0,
+				"device_sdc_type_sat_attr_unknown_ssd_attribute_decoded":      4694419309637,
+				"device_sdc_type_sat_attr_unknown_ssd_attribute_normalized":   4,
+				"device_sdc_type_sat_attr_unknown_ssd_attribute_raw":          4694419309637,
+				"device_sdc_type_sat_power_cycle_count":                       13,
+				"device_sdc_type_sat_power_on_time":                           29678400,
+				"device_sdc_type_sat_smart_status_failed":                     0,
+				"device_sdc_type_sat_smart_status_passed":                     1,
+				"device_sdc_type_sat_temperature":                             27,
+			},
+		},
 		"success type nvme devices": {
 			prepareMock: prepareMockOkTypeNvme,
 			wantCharts:  4,
